@@ -89,9 +89,7 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
 
             # Drone sends data specified by the user to the base station if ML is not running on board
             # TODO:
-            # t1 = time.time()
-            # self.send_msg(msg="test", emitter_devices=emitter_devices)
-            # t2 = time.time()
+
             # comm_transmit_time += t2 - t1
             # t1 = time.time()
             # received_messages = self.receive_msgs(receiver_devices=receiver_devices)
@@ -101,8 +99,14 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
             # Execute prediction pipeline step
             if self.model is not None:
                 prediction = self.model.predict()
+                # t1 = time.time()
+                # self.send_msg(msg=str(prediction), emitter_devices=emitter_devices)
+                # t2 = time.time()
+                # comm_transmit_time += t2 - t1
+
                 if prediction is not None:
                     print(prediction)
+
             # Get energy values on each cycle
             energy = {**self.get_processing_energy(),
                       **self.get_communication_energy(comm_transmit_time=comm_transmit_time, comm_receive_time=comm_receive_time),
@@ -118,8 +122,9 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
 
             # Update log data every 5 minutes with energy values
             print(energy, f'\n{self.battery.remaining_energy_percentage * 100}% battery remaining')
-            with open('logs/ML_on_drone.json', 'a') as logfile:
+            with open('logs/ML_on_station.json', 'a+') as logfile:
                 json.dump(energy, logfile)
+                logfile.write('\n')
 
 
 class AutopilotMavic2DJI(AutopilotControlledDrone):
